@@ -1,9 +1,12 @@
+import logging
 from json import JSONDecodeError, dumps, loads
 from pydoc import locate
 
 from pika import BlockingConnection, ConnectionParameters, PlainCredentials, URLParameters
 
 
+logger = logging.getLogger(__name__)
+
 class RabbitWrapper:
     CONFIG = {}
 
@@ -164,15 +167,18 @@ class CallbackWrapper:
 
     def msg_ack(self):
         self.channel.basic_ack(delivery_tag=self.method.delivery_tag)
+        logger.info(f"message ack successful")
 
     def msg_resend(self, data, queue=None, json=True):
         self.validate_wrapper_started("msg_resend")
         self.WRAPPER.msg_send(data, queue, json=json)
+        logger.info(f"re-inserted message on queue. queue: {queue}")
 
     def msg_deadletter(self, data, queue=None, json=True):
         self.validate_wrapper_started("msg_deadletter")
         deadletter = queue or self.WRAPPER.get_deadletter()
         self.WRAPPER.msg_send(data, queue=deadletter, json=json)
+        logger.info(f"moved message to deadletter queue. queue: {deadletter}")
 
     def consume_data(self, raw_msg):
         raise Exception('Implement your owner "consume_data" function')
@@ -191,9 +197,12 @@ class CallbackWrapper:
         try:
             return loads(data)
         except (TypeError, JSONDecodeError) as e:
+            logger.info("invalid json message.")
             if deadletter_on_error:
+                logger.info("invalid json message, request to move to deadletter queue")
                 self.msg_deadletter(data=data, json=False)
             if ack_on_error:
+                logger.info("invalid json message, request ack")
                 self.msg_ack()
 
     ###
@@ -201,4 +210,4 @@ class CallbackWrapper:
     ###
     def get_rabbit_instance(self):
         if bool(self.NAME) or bool(self.CONFIG):
-            self.wrapper = RabbitWrapper(name=self.NAME, config=self.CONFIG, channel=self.channel)
+            self.WRAPPER = RabbitWrapper(name=self.NAME, config=self.CONFIG, channel=self.channel)
